#
# spec file for package libxml++40
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _name   libxml++
%define so_ver  4_0-1
%define base_ver 4.0

Name:           libxml++40
Version:        4.0.2
Release:        bp155.1.7
Summary:        C++ Interface for XML Files
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
URL:            https://libxmlplusplus.github.io/libxmlplusplus
Source0:        https://download.gnome.org/sources/libxml++/%{base_ver}/%{_name}-%{version}.tar.xz

BuildRequires:  c++_compiler
BuildRequires:  fdupes
BuildRequires:  meson >= 0.55.0
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(glibmm-2.68)
BuildRequires:  pkgconfig(libxml-2.0) >= 2.7.7

%description
libXML++ provides a C++ interface for XML files. It presently uses
libxml2 to access the XML files.

%package -n libxml++-%{so_ver}
Summary:        C++ Interface for XML Files
Group:          Development/Libraries/C and C++
Provides:       %{name} = %{version}
Obsoletes:      %{name} < %{version}

%description -n libxml++-%{so_ver}
libXML++ provides a C++ interface for XML files. It presently uses
libxml2 to access the XML files.

%package devel
Summary:        C++ Interface for XML Files -- Development Files
Group:          Development/Libraries/C and C++
Requires:       glibmm2-devel
Requires:       libxml++-%{so_ver} = %{version}

%description devel
This package contains all necessary include files and libraries needed
to develop applications that require these.

%prep
%autosetup -p1 -n %{_name}-%{version}
chmod -x NEWS libxml++config.h.in libxml++config.h.meson

%build
%meson \
	%{nil}
%meson_build

%install
%meson_install
%fdupes %{buildroot}%{_prefix}

%ldconfig_scriptlets -n libxml++-%{so_ver}

%files -n libxml++-%{so_ver}
%license COPYING
%doc AUTHORS ChangeLog NEWS README
%{_libdir}/*.so.*

%files devel
%{_includedir}/libxml++-%{base_ver}
%dir %{_libdir}/libxml++-%{base_ver}
%dir %{_libdir}/libxml++-%{base_ver}/include
%{_libdir}/libxml++-%{base_ver}/include/*.h
%{_libdir}/pkgconfig/*.pc
%{_libdir}/*.so

%changelog
* Sun Sep 11 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.0.2:
  + Document, Node: Recognize HTML documents
  + Parsers: Avoid std::getline for istream inputs
  + Build:
  - Meson build:
    . When mm-common >= 1.0.4 is used, Perl is not required
    . Require meson >= 0.55.0
    . Specify 'check' option in run_command(). Will be necessary
    with future versions of Meson.
    . Avoid configuration warnings
  - Win32: Don't include afxres.h in resources.
  - Support Visual Studio 2022
  - docs/manual: Sort example file lists. See
    glgo/GNOME/gtkmm-documentation/!15
  - NMake Makefiles: Make things more configurable.
  + Documentation:
  - docs/manual: Upgrade from DocBook 4.1 to DocBook 5.0
  - MSVC_NMake/README: Document dependency placement
- Changes from version 4.0.1:
  + Build:
  - libxml++config.h.*: Don't dllimport on MinGW
  - Meson build:
    . Make it possible to use libxml++ as a subproject
    . No implicit_include_directories
  - MSVC build: Export classes selectively
  + Documentation: Let links point to libxml++-3.0 versions instead
    of latest versions.
- Drop erroneous executable bit from docs and headerfiles.
- Use ldconfig_scriptlets macro for post(un) handling.
* Wed May 19 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Drop baselibs.conf: this was just added as the package was based
  off libxml++-3.0, but there is no consumer for it.
* Mon Dec 28 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Inital build for openSUSE.
